Edge

Struct Edge 

pub struct Edge<K, N, E>(pub Node<K, N, E>, pub Node<K, N, E>, pub E)
where
    K: Clone + Hash + PartialEq + Eq + Display,
    N: Clone,
    E: Clone;
An edge between nodes is a tuple struct Edge(u, v, e) where u is the source node, v is the target node, and e is the edge’s value.

Tuple Fields

0: Node<K, N, E>1: Node<K, N, E>2: E

Implementations

Source

impl<K, N, E> Edge<K, N, E>
where K: Clone + Hash + PartialEq + Eq + Display, N: Clone, E: Clone,

pub fn source(&self) -> &Node<K, N, E>

Returns the source node of the edge.

pub fn target(&self) -> &Node<K, N, E>

Returns the target node of the edge.

pub fn value(&self) -> &E

Returns the edge’s value.

pub fn reverse(&self) -> Edge<K, N, E>

Reverse the edge’s direction.